| dr_scale_attenuation | R Documentation |
Returns the proportional reduction in fitted residual between-study
heterogeneity between two design-robustness values,
A_\tau = 1 - \exp(-\gamma (d_H - d_L)). This is a summary of the
fitted scale function only. It is not a causal R^2, not a proportion
of heterogeneity explained, and not evidence that design quality caused a
reduction in heterogeneity.
dr_scale_attenuation(object, d_low = min(object$dr), d_high = max(object$dr))
object |
A fitted |
d_low |
Lower DR value; defaults to the observed minimum. |
d_high |
Higher DR value; defaults to the observed maximum. |
A single numeric value. For a constrained fit it lies in
[0, 1); for an unrestricted fit with a negative gradient it is
negative, indicating heterogeneity that increases with the design index.
path <- system.file("extdata", "bcg_design_robustness.csv", package = "drmeta")
bcg <- utils::read.csv(path)
fit <- drmeta(yi = bcg[["yi"]], vi = bcg[["vi"]], dr = bcg[["dr"]])
dr_scale_attenuation(fit)
dr_scale_attenuation(fit, d_low = 0.25, d_high = 0.75)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.