| normalize_01 | R Documentation |
Rescale a numeric vector to the unit interval
normalize_01(x)
x |
A numeric vector. Missing values are ignored during rescaling and preserved in the result. |
A numeric vector of the same length rescaled to [0, 1]. If all
non-missing values are equal, a zero vector is returned.
normalize_01(c(2, 5, 8))
normalize_01(c(1, 1, 1))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.